=======
History
=======

0.5.0 (2019-06-24)
------------------

* Changed implementation of LinkPrediction ranks by moving functions to model methods.
* Implemented RESCAL.


0.4.0 (2019-05-15)
------------------

* Fixed a major bug/problem in the Evaluation protocol of LinkPrediction.

0.3.1 (2019-05-10)
------------------

* Minor bug fixes in the various normalization functions.

0.3.0 (2019-05-09)
------------------

* Fixed CUDA support.

0.2.0 (2019-05-07)
------------------

* Added support for filtered performance measures.

0.1.7 (2019-04-03)
------------------

* First real release on PyPI.

0.1.0 (2019-04-01)
------------------

* First release on PyPI.
